#-----------------------------------------------------------------------------#
#
#  \Program Files\HW2-MSB.awk                                      Version 1.1
#
#  Written by:  NemesisChiken
#               May 23, 2004
#
#  This AWK program will scan through all of the Homeworld 2 .stats files in
#  a given players profile directory and generate an HTML summary of all the
#  results.
#
#  Syntax:  gawk -f HW2-MSB.awk (filelist)
#
#           where:  (filelist) = list of files to process
#
#-----                      A U D I T   T R A I L                        -----#
#
#   Date    Who   Description of Change
# ======== ===== =============================================================
# 05/26/04  rbm  Added this documentation
# 05/27/04  rbm  Added short game filtering to remove "bad" games
# 05/28/04  rbm  Updated Win Ratio to display as percent also
#                Added game color bars to seperate different games
#                Added logic to automatically select initial Player
#                Added Total Games to Career Summary Table
#                Change -ANY- select option to filter checkbox
# 05/29/04  rbm  Added popup of Game Details window
# 05/30/04  rbm  Fixed missing percent sign in popup window
#                Improved file name parsing for date / time
# Version 1.1
# 06/02/04  rbm  Changed sort order to timestamp in game list
# 06/03/04  rbm  Added Bar Graph popup window
#           rbm  Changed Lives/Died back to Win/Loss
#
#-----------------------------------------------------------------------------#
#  Define program variables
#-----------------------------------------------------------------------------#

BEGIN{ ShortGame=5

       minPlayer=6
       maxPlayer=0
       Player=0
       aryCnt=0
       mapCnt=1
       plyCnt=1
       racCnt=1
       lMap=""

       maxGames=0
       avatarPlayer=""

#-----------------------------------------------------------------------------#
#  Build HTML Header
#-----------------------------------------------------------------------------#

       print "<html><head><title>NemesisChiken's Multiplayer Stats Page</title>"

#-----------------------------------------------------------------------------#
#  Define JavaScript Global variables
#-----------------------------------------------------------------------------#

       print "<script language=\"JavaScript\">"
       print "<!-- Begin"
       print "var ShipsBuilt=0;"
       print "var ShipsLost=0;"
       print "var ShipsKilled=0;"
       print "var ShipsCaptured=0;"
       print "var CombatScore=0;"
       print "var RUsHarvested=0;"
       print "var RUsSpent=0;"
       print "var Collectors=0;"
       print "var Refineries=0;"
       print "var ResourceScore=0;"
       print "var ProdVessels=0;"
       print "var Subsystems=0;"
       print "var PctResearch=0;"
       print "var RUsResearch=0;"
       print "var BuildScore=0;"
       print "var RUsReceived=0;"
       print "var RUsDonated=0;"
       print "var TimeDied=0;"
       print "var GameMins=0;"
       print "var DiplomacyScore=0;"
       print "var CarScore=0;"
       print "var CarWins=0;"
       print "var CarLost=0;"
       print "var CarKill=0;"
       print "var CarCount=0;"
       print "var Ratio=0;"
       print "var CalcType=1;"
       print " "
       print "var ShortGame="ShortGame";"
       print "var lMapSel=\" \";"
       print "var lPlayerSel=\" \";"
       print "var lRaceSel=\" \";"
       print " "

#-----------------------------------------------------------------------------#
#  Define Stats Data Header Array
#-----------------------------------------------------------------------------#

       print "var headArry=new Array(\"Map\",\"Time Stamp\",\"Reserved\",\"Player\",\"Race\",\"Pos\",\"Ships Built\",\"Ships Lost\",\"Ships Killed\",\"Ships Captured\",\"Combat Score\",\"RUs Harvested\",\"RUs Spent\",\"Collectors\",\"Refineries\",\"Resource Score\",\"Prod Vessels\",\"Subsystems\",\"Pct Research\",\"RUs Research\",\"Build Score\",\"RUs Received\",\"RUs Donated\",\"TimeDied\",\"Game Mins\",\"Diplomacy Score\");"

#-----------------------------------------------------------------------------#
#  Build Stats Data Array
#-----------------------------------------------------------------------------#

       print "var statArry=new Array("
     }

#-----------------------------------------------------------------------------#
#  Grab New Map Name 
#-----------------------------------------------------------------------------#

/^  MapName/ {if( length($3)>1 ) {
                eqPos=index($0,"=")+3
                MapName=substr($0,eqPos,length($0)-eqPos-1)
               }
               else {
                 newName=""
                 while( $1 != "0," ) {
                   getline
                   ascChar=int($1)
                   if( ascChar && ascChar != 39 ) {
                     newName=sprintf("%s%c",newName,ascChar)
                   }
                 }
                 MapName=newName
               }

#-----------------------------------------------------------------------------#
#  Dump out completed previous game players stats if not first .stats file 
#-----------------------------------------------------------------------------#

              if( lMap != "" ) {
                for(i=minPlayer ; i<=maxPlayer ; i++ ) {
                  if( stats[i,43] == "--:--:--" ) stats[i,44] = GameMins
                  printf("new Array(\"%s\",\"%s %s\",\"%s\",\"%s\",\"%s\",\"%s\",",lMap,gDate,gTime,0,stats[i,01],stats[i,02],stats[i,03])
                  printf("%s,%s,%s,%s,%s,",stats[i,11],stats[i,12],stats[i,13],stats[i,14],stats[i,15])
                  printf("%s,%s,%s,%s,%s,",stats[i,21],stats[i,22],stats[i,23],stats[i,24],stats[i,25])
                  printf("%s,%s,%s,%s,%s,",stats[i,31],stats[i,32],stats[i,33],stats[i,34],stats[i,35])
                  printf("%s,%s,\"%s\",%s,%s),\n",stats[i,41],stats[i,42],stats[i,43],stats[i,44],stats[i,45])
                  aryCnt++
                }
              }
              lMap=MapName
              cntMap[MapName]++
              rcF=split(FILENAME,MQN,"_")
              rcM=split(MQN[rcF-3],FQN,"[-:]")
              gDate=sprintf("%4d/%02d/%02d",FQN[3],FQN[1],FQN[2])
              gTime=sprintf("%02d:%02d",MQN[rcF-2],MQN[rcF-1])
              minPlayer=6
              maxPlayer=0
              Player=0
             }

#-----------------------------------------------------------------------------#
#  Grab new Player Position
#-----------------------------------------------------------------------------#

/^  Player/ {Player++
             stats[Player,03]=substr($1,7,1)+1
             if( Player < minPlayer ) minPlayer = Player
             if( Player > maxPlayer ) maxPlayer = Player
            }

#-----------------------------------------------------------------------------#
#  Grab new Player Name
#-----------------------------------------------------------------------------#

/^      Name/ {if( length($3)>3 ) stats[Player,01] = substr($3,2,length($3)-3)
               else {
                 newName=""
                 while( $1 != "0," ) {
                   getline
                   ascChar=int($1)
                   if( ascChar ) newName=sprintf("%s%c",newName,ascChar)
                 }
                 stats[Player,01] = newName
               }
               cntName[stats[Player,01]]++
               if ( cntName[stats[Player,01]] > maxGames ) {
                 avatar=stats[Player,01]
                 maxGames=cntName[stats[Player,01]]
               }
              }

#-----------------------------------------------------------------------------#
#  Grab Players Race in game
#-----------------------------------------------------------------------------#

/^      Race/ {stats[Player,02] = substr($3,2,length($3)-3)
               cntRace[stats[Player,02]]++
              }

#-----------------------------------------------------------------------------#
#  Grab Players Combat Statistics
#-----------------------------------------------------------------------------#

/^      TotalShipsBuilt/ {stats[Player,11] = substr($3,1,length($3)-1)}
/^      TotalShipsLost/ {stats[Player,12] = substr($3,1,length($3)-1)}
/^      TotalShipsDestroyed/ {stats[Player,13] = substr($3,1,length($3)-1)}
/^      TotalShipsCaptured/ {stats[Player,14] = substr($3,1,length($3)-1)}
/^      CombatTotal/ {stats[Player,15] = substr($3,1,length($3)-1)}

#-----------------------------------------------------------------------------#
#  Grab Players Resourcing Statistics
#-----------------------------------------------------------------------------#

/^      TotalRUHarvested/ {stats[Player,21] = substr($3,1,length($3)-1)}
/^      TotalRUSpent/ {stats[Player,22] = substr($3,1,length($3)-1)}
/^      ResourceCollectors/ {stats[Player,23] = substr($3,1,length($3)-1)}
/^      MobileRefineries/ {stats[Player,24] = substr($3,1,length($3)-1)}
/^      ResourceTotal/ {stats[Player,25] = substr($3,1,length($3)-1)}
 
#-----------------------------------------------------------------------------#
#  Grab Players Building Statistics
#-----------------------------------------------------------------------------#

/^      BuildCapableShips/ {stats[Player,31] = substr($3,1,length($3)-1)}
/^      TotalSubsystems/ {stats[Player,32] = substr($3,1,length($3)-1)}
/^      Research%/ {stats[Player,33] = substr($3,1,length($3)-1)}
/^      ResearchCost/ {stats[Player,34] = substr($3,1,length($3)-1)}
/^      BuildingTotal/ {stats[Player,35] = substr($3,1,length($3)-1)}

#-----------------------------------------------------------------------------#
#  Grab Players Diplomacy Statistics
#-----------------------------------------------------------------------------#

/^      TributeReceived/ {stats[Player,41] = substr($3,1,length($3)-1)}
/^      TributeDonated/ {stats[Player,42] = substr($3,1,length($3)-1)}
/^      TimeOfDeath/ {if( substr($3,2,2) == "--" ) {
                        stats[Player,43] = "--:--:--"
                        stats[Player,44] = 0
                      } else {
                        rc=split(substr($3,2,length($3)-3),TOD,":")
                        stats[Player,43] = sprintf("%02d:%02d:%02d",TOD[1],TOD[2],TOD[3])
                        stats[Player,44] = TOD[1]*60+TOD[2]+int(TOD[3]/30)
                      }
                     }
/^      DiplomacyTotal/ {stats[Player,45] = substr($3,1,length($3)-1)}

#-----------------------------------------------------------------------------#
#  Grab Total Time of Game
#-----------------------------------------------------------------------------#

/^  TotalTime/ {rc=split(substr($5,1,length($5)-2),TOD,":")
                GameTime = sprintf("%02d:%02d:%02d",TOD[1],TOD[2],TOD[3])
                GameMins = TOD[1]*60+TOD[2]+int(TOD[3]/30)
               }

#-----------------------------------------------------------------------------#
#  End of all files found, dump out last games players stats
#-----------------------------------------------------------------------------#

END {
     for(i=minPlayer ; i<=maxPlayer ; i++ ) {
       if( stats[i,43] == "--:--:--" ) stats[i,44] = GameMins
       printf("new Array(\"%s\",\"%s %s\",\"%s\",\"%s\",\"%s\",\"%s\",",lMap,gDate,gTime,0,stats[i,01],stats[i,02],stats[i,03])
       printf("%s,%s,%s,%s,%s,",stats[i,11],stats[i,12],stats[i,13],stats[i,14],stats[i,15])
       printf("%s,%s,%s,%s,%s,",stats[i,21],stats[i,22],stats[i,23],stats[i,24],stats[i,25])
       printf("%s,%s,%s,%s,%s,",stats[i,31],stats[i,32],stats[i,33],stats[i,34],stats[i,35])
       printf("%s,%s,\"%s\",%s,%s),\n",stats[i,41],stats[i,42],stats[i,43],stats[i,44],stats[i,45])
       aryCnt++
     }

#-----------------------------------------------------------------------------#
#  End of Stats Array
#-----------------------------------------------------------------------------#

     print "new Array(\" \",\" \")"
     print ");"
     print " "
     print "var ArryCNT="aryCnt";"
     print " "

#-----------------------------------------------------------------------------#
#  Build Game Detail Line display flag array
#-----------------------------------------------------------------------------#

     print "var lineArry=new Array(\" \");"
     print "if ( ArryCNT > 0 ) {"
     print "  for (i = 0; i < ArryCNT; i++) {"
     print "    lineArry[i]=1;"
     print "  }"
     print "  lineArry.length = ArryCNT-1;"
     print "}"
     print " "

#-----------------------------------------------------------------------------#
#  Function to perform initial sort of Stats Array
#-----------------------------------------------------------------------------#

     print "function sortByTime(a,b) {"
     print "  if (a[1]<b[1]) return 1;"
     print "  if (a[1]>b[1]) return -1;"
     print "  return 0;"
     print "}"
     print " "

#-----------------------------------------------------------------------------#
#  Main function to drive detail game lines display
#-----------------------------------------------------------------------------#

     print "function fillLineArray(selectCtrl, itemArray, C) {"
     print "var C, i, j;"
     print " "
     print "//var AVARI = \"document.main.COL\"+C+\".value\";"
     print "//var AVALU = eval( AVARI );"
     print "//alert(\"got here from column \"+C+\" with var \"+AVARI+\" with value \"+AVALU);"
     print " "
     print "  if ( ArryCNT > 0 ) {"
     print "    document.main.SYSTATUS.value=\"SEARCHING RESULTS\";"
     print "    buildLineArray( selectCtrl, itemArray );"
     print "    j = fillSelectArray( selectCtrl, itemArray );"
     print "    document.main.SYSTATUS.value=j + \" OF "aryCnt" ROWS DISPLAYED\";"
     print "  } else {"
     print "    document.main.SYSTATUS.value=\"NO ROWS LOADED\";"
     print "    document.main.HEADER.options[0] = new Option(\"NO DATA FOUND\");"
     print "    selectCtrl.options[0] = new Option(\"RESULTS EMPTY\");"
     print "  }"
     print "}"
     print " "

#-----------------------------------------------------------------------------#
#  Main routine to filter game lines based on Map, Player, and Race
#-----------------------------------------------------------------------------#

     print "function buildLineArray(selectCtrl, itemArray) {"
     print "var i, j;"
     print "  if (itemArray != null) {"
     print " "
     print "    var COL0v = document.main.COL0.value;"
     print "    var COL3v = document.main.COL3.value;"
     print "    var COL4v = document.main.COL4.value;"
     print " "
     print "    for (i = 0; i < itemArray.length; i++) {"
     print " "
     print "      var TFLG=\"keep\";"
     print " "
     print "      if( document.main.MapFilter.checked ) {"
     print "        if (COL0v != itemArray[i][0]) {"
     print "          lineArry[i] = 0;"
     print "          TFLG=\"drop-col0-rec\"+i+\"-mis=\"+itemArray[i][0]+\"=\"+COL0v+\"=\";"
     print "        }"
     print "      }"
     print " "
     print "      if( document.main.PlayerFilter.checked ) {"
     print "        if (COL3v != itemArray[i][3]) {"
     print "          lineArry[i] = 0;"
     print "          TFLG=\"drop-col3-rec\"+i+\"-mis=\"+itemArray[i][3]+\"=\"+COL3v+\"=\";"
     print "        }"
     print "      }"
     print " "
     print "      if( document.main.RaceFilter.checked ) {"
     print "        if (COL4v != itemArray[i][4]) {"
     print "          lineArry[i] = 0;"
     print "          TFLG=\"drop-col4-rec\"+i+\"-mis=\"+itemArray[i][4]+\"=\"+COL4v+\"=\";"
     print "        }"
     print "      }"
     print " "
     print "      if( document.main.ShortGames.checked ) {"
     print "        if ( itemArray[i][24] < ShortGame ) {"
     print "          lineArry[i] = 0;"
     print "          TFLG=\"drop-game-rec\"+i+\"-short=\"+itemArray[i][24]+\"=\";"
     print "        }"
     print "      }"
     print " "
     print "      if (TFLG == \"keep\" ) {"
     print "        lineArry[i] = 1;"
     print "        TFLG=\"keep-rec\"+i+\"=\";"
     print "      }"
     print " "
     print "    }"
     print "  }"
     print "}"
     print " "

#-----------------------------------------------------------------------------#
#  Generate the Header Line, build and populate detail game display lines
#-----------------------------------------------------------------------------#

     print "function fillSelectArray(selectCtrl, itemArray) {"
     print "var curMap, f, i, j, lastMap, lineCode, NIA;"
     print " "
     print "//alert(\"In fileSelectArray\");"
     print "// empty existing items"
     print " "
     print "  for (i = selectCtrl.options.length; i >= 0; i--) {"
     print "    selectCtrl.options[i] = null; "
     print "  }"
     print " "
     print "  if (itemArray != null) {"
     print " "
     print "// add new headings"
     print " "
     print "    j = 0;"
     print "    NIA = \" \";"
     print " "
     print "    PIA = headArry[0] + \"_______________________________________________________________________________________________________________________________________________________________________________________________________________________________________________\";"
     print "    NIA = NIA + PIA.substring(0,document.main.COLSZ0.value);"
     print " "
     print "    PIA = headArry[1] + \"_______________________________________________________________________________________________________________________________________________________________________________________________________________________________________________\";"
     print "    NIA = NIA + PIA.substring(0,document.main.COLSZ1.value);"
     print " "
#    print "    PIA = headArry[2] + \"_______________________________________________________________________________________________________________________________________________________________________________________________________________________________________________\";"
#    print "    NIA = NIA + PIA.substring(0,document.main.COLSZ2.value);"
#    print " "
     print "    PIA = headArry[3] + \"_______________________________________________________________________________________________________________________________________________________________________________________________________________________________________________\";"
     print "    NIA = NIA + PIA.substring(0,document.main.COLSZ3.value);"
     print " "
     print "    PIA = headArry[4] + \"_______________________________________________________________________________________________________________________________________________________________________________________________________________________________________________\";"
     print "    NIA = NIA + PIA.substring(0,document.main.COLSZ4.value);"
     print " "
     print "    PIA = headArry[5] + \"_______________________________________________________________________________________________________________________________________________________________________________________________________________________________________________\";"
     print "    NIA = NIA + PIA.substring(0,document.main.COLSZ5.value);"
     print " "
     print "    PIA = headArry[23] + \"_______________________________________________________________________________________________________________________________________________________________________________________________________________________________________________\";"
     print "    NIA = NIA + PIA.substring(0,document.main.COLSZ23.value);"
     print " "
     print "    NIA += \" \";"
     print "    document.main.HEADER.options[0] = new Option(NIA);"
     print "    document.main.HEADER.options[0].style.backgroundColor = \"#000000\";"
     print "    document.main.HEADER.options[0].style.color = \"#FFFFFF\";"
     print " "

#-----------------------------------------------------------------------------#
#  Reset all Table totals for new display
#-----------------------------------------------------------------------------#

     print "    ShipsBuilt=0;"
     print "    ShipsLost=0;"
     print "    ShipsKilled=0;"
     print "    ShipsCaptured=0;"
     print "    CombatScore=0;"
     print "    RUsHarvested=0;"
     print "    RUsSpent=0;"
     print "    Collectors=0;"
     print "    Refineries=0;"
     print "    ResourceScore=0;"
     print "    ProdVessels=0;"
     print "    Subsystems=0;"
     print "    PctResearch=0;"
     print "    RUsResearch=0;"
     print "    BuildScore=0;"
     print "    RUsReceived=0;"
     print "    RUsDonated=0;"
     print "    TimeDied=0;"
     print "    GameMins=0;"
     print "    DiplomacyScore=0;"
     print "    CarScore=0;"
     print "    CarWins=0;"
     print "    CarLost=0;"
     print "    CarKill=0;"
     print "    CarCount=0;"
     print "    Ratio=0;"
     print " "
     print "    lastMap=\" \";"
     print "    lineCode=0;"
     print " "

#-----------------------------------------------------------------------------#
#  Loop through all Stats Array lines and process if flagged to display
#-----------------------------------------------------------------------------#

     print "    for (i = 0; i < itemArray.length-1; i++) {"
     print "      if ( lineArry[i] == 1 ) {"
     print " "

#-----------------------------------------------------------------------------#
#  Include game statistics for totals
#-----------------------------------------------------------------------------#

     print "        ShipsBuilt += itemArray[i][6];"
     print "        ShipsLost += itemArray[i][7];"
     print "        ShipsKilled += itemArray[i][8];"
     print "        ShipsCaptured += itemArray[i][9];"
     print "        CombatScore += itemArray[i][10];"
     print "        CarScore += itemArray[i][10];"
     print "        RUsHarvested += itemArray[i][11];"
     print "        RUsSpent += itemArray[i][12];"
     print "        Collectors += itemArray[i][13];"
     print "        Refineries += itemArray[i][14];"
     print "        ResourceScore += itemArray[i][15];"
     print "        CarScore += itemArray[i][15];"
     print "        ProdVessels += itemArray[i][16];"
     print "        Subsystems += itemArray[i][17];"
     print "        PctResearch += itemArray[i][18];"
     print "        RUsResearch += itemArray[i][19];"
     print "        BuildScore += itemArray[i][20];"
     print "        CarScore += itemArray[i][20];"
     print "        RUsReceived += itemArray[i][21];"
     print "        RUsDonated += itemArray[i][22];"
     print "        if ( itemArray[i][23] == \"--:--:--\" ) CarWins++;"
     print "        else {"
     print "          TimeDied += itemArray[i][24];"
     print "          CarLost++;"
     print "        }"
     print "        GameMins += itemArray[i][24];"
     print "        DiplomacyScore += itemArray[i][25];"
     print "        CarScore += itemArray[i][25];"
     print " "
     print "        CarCount++;"
     print " "

#-----------------------------------------------------------------------------#
#  Insert detail line into display area if still room for it
#-----------------------------------------------------------------------------#

     print "        if ( j < document.main.RECLST.value) {"
     print "          NIA = \" \";"
     print " "
     print "          PIA = \"______________________________________________________________________________________________________________________________________________________________________________________________________________________________________________________________\";"
     print "          if( itemArray[i][0] ) PIA = itemArray[i][0] + PIA;"
     print "          NIA = NIA + PIA.substring(0,document.main.COLSZ0.value);"
     print " "
     print "          PIA = \"______________________________________________________________________________________________________________________________________________________________________________________________________________________________________________________________\";"
     print "          if( itemArray[i][1] ) PIA = itemArray[i][1] + PIA;"
     print "          NIA = NIA + PIA.substring(0,document.main.COLSZ1.value);"
     print " "
#    print "          PIA = \"______________________________________________________________________________________________________________________________________________________________________________________________________________________________________________________________\";"
#    print "          if( itemArray[i][2] ) PIA = itemArray[i][2] + PIA;"
#    print "          NIA = NIA + PIA.substring(0,document.main.COLSZ2.value);"
#    print " "
     print "          curMap = NIA;"
     print " "
     print "          PIA = \"______________________________________________________________________________________________________________________________________________________________________________________________________________________________________________________________\";"
     print "          if( itemArray[i][3] ) PIA = itemArray[i][3] + PIA;"
     print "          NIA = NIA + PIA.substring(0,document.main.COLSZ3.value);"
     print " "
     print "          PIA = \"______________________________________________________________________________________________________________________________________________________________________________________________________________________________________________________________\";"
     print "          if( itemArray[i][4] ) PIA = itemArray[i][4] + PIA;"
     print "          NIA = NIA + PIA.substring(0,document.main.COLSZ4.value);"
     print " "
     print "          PIA = \"______________________________________________________________________________________________________________________________________________________________________________________________________________________________________________________________\";"
     print "          if( itemArray[i][5] ) PIA = itemArray[i][5] + PIA;"
     print "          NIA = NIA + PIA.substring(0,document.main.COLSZ5.value);"
     print " "
     print "          PIA = \"______________________________________________________________________________________________________________________________________________________________________________________________________________________________________________________________\";"
     print "          if( itemArray[i][23] != \"--:--:--\" ) PIA = itemArray[i][23] + PIA;"
     print "          NIA = NIA + PIA.substring(0,document.main.COLSZ23.value);"
     print " "
     print "          NIA += \" \";"
     print "          opts = document.main.TEMPLAT.options;"
     print "          opts[j] = new Option(NIA);"
     print " "
     print "          if( lastMap != curMap ) lineCode = !lineCode"
     print "          if( lineCode ) {"
     print "            opts[j].style.backgroundColor = \"#CCCCCC\" ;"
     print "            opts[j].style.color = \"#000000\" ;"
     print "          } else {"
     print "            opts[j].style.backgroundColor = \"#99CCFF\" ;"
     print "            opts[j].style.color = \"#000000\" ;"
     print "          }"
     print "          lastMap=curMap;"

     print "          if( itemArray[i][23] != \"--:--:--\" &&  lineCode ) opts[j].style.color = \"#FF00CC\" ;"
     print "          if( itemArray[i][23] != \"--:--:--\" && !lineCode ) opts[j].style.color = \"#FF3333\" ;"

     print " "
     print "          if (itemArray[i] != null) {"
     print "            selectCtrl.options[j].value = i; "
     print "          }"
     print "          j++;"
     print "        }"
     print "      }"
     print "    }"
     print "  }"
     print "  fillTableStats(1);"
     print "  return(j);"
     print " "
     print "}"
     print " "

#-----------------------------------------------------------------------------#
#  Function to calculate and populate all Summary Table items
#-----------------------------------------------------------------------------#

     print "function fillTableStats(aType) {"
     print "var weight=1;"
     print " "
     print "    CalcType=aType;"
     print " "
     print "    if ( CalcType == 1 || CarCount == 0 ) weight=1;"
     print "    else weight=CarCount;"
     print " "

#-----------------------------------------------------------------------------#
#  Figure out Combat results
#-----------------------------------------------------------------------------#

     print "    var wShipsBuilt=ShipsBuilt/weight;"
     print "    wShipsBuilt=parseInt(wShipsBuilt,10);"
     print "    var wShipsLost=ShipsLost/weight;"
     print "    wShipsLost=parseInt(wShipsLost,10);"
     print "    var wShipsKilled=ShipsKilled/weight;"
     print "    wShipsKilled=parseInt(wShipsKilled,10);"
     print "    var wShipsCaptured=ShipsCaptured/weight;"
     print "    wShipsCaptured=parseInt(wShipsCaptured,10);"
     print "    var wCombatScore=CombatScore/weight;"
     print "    wCombatScore=parseInt(wCombatScore,10);"
     print " "
     print "    document.main.ShipsBuilt.value=wShipsBuilt;"
     print "    document.main.ShipsLost.value=wShipsLost;"
     print "    document.main.ShipsKilled.value=wShipsKilled;"
     print "    document.main.ShipsCaptured.value=wShipsCaptured;"
     print "    document.main.CombatScore.value=wCombatScore;"
     print " "

#-----------------------------------------------------------------------------#
#  Figure out Resourcing results
#-----------------------------------------------------------------------------#

     print "    var wRUsHarvested=RUsHarvested/weight;"
     print "    wRUsHarvested=parseInt(wRUsHarvested,10);"
     print "    var wRUsSpent=RUsSpent/weight;"
     print "    wRUsSpent=parseInt(wRUsSpent,10);"
     print "    var wCollectors=Collectors/weight;"
     print "    wCollectors=parseInt(wCollectors,10);"
     print "    var wRefineries=Refineries/weight;"
     print "    wRefineries=parseInt(wRefineries,10);"
     print "    var wResourceScore=ResourceScore/weight;"
     print "    wResourceScore=parseInt(wResourceScore,10);"
     print " "
     print "    document.main.RUsHarvested.value=wRUsHarvested;"
     print "    document.main.RUsSpent.value=wRUsSpent;"
     print "    document.main.Collectors.value=wCollectors;"
     print "    document.main.Refineries.value=wRefineries;"
     print "    document.main.ResourceScore.value=wResourceScore;"
     print " "

#-----------------------------------------------------------------------------#
#  Figure out Building results
#-----------------------------------------------------------------------------#

     print "    var wProdVessels=ProdVessels/weight;"
     print "    wProdVessels=parseInt(wProdVessels,10);"
     print "    var wSubsystems=Subsystems/weight;"
     print "    wSubsystems=parseInt(wSubsystems,10);"
     print "    if ( CarCount ) {"
     print "      var wPctResearch=PctResearch/CarCount;"
     print "      wPctResearch=parseInt(wPctResearch,10);"
     print "    } else wPctResearch=0;"
     print "    var wRUsResearch=RUsResearch/weight;"
     print "    wRUsResearch=parseInt(wRUsResearch,10);"
     print "    var wBuildScore=BuildScore/weight;"
     print "    wBuildScore=parseInt(wBuildScore,10);"
     print " "
     print "    document.main.ProdVessels.value=wProdVessels;"
     print "    document.main.Subsystems.value=wSubsystems;"
     print "    document.main.PctResearch.value=wPctResearch;"
     print "    document.main.RUsResearch.value=wRUsResearch;"
     print "    document.main.BuildScore.value=wBuildScore;"
     print " "

#-----------------------------------------------------------------------------#
#  Figure out Diplomacy results
#-----------------------------------------------------------------------------#

     print "    var wRUsReceived=RUsReceived/weight;"
     print "    wRUsReceived=parseInt(wRUsReceived,10);"
     print "    var wRUsDonated=RUsDonated/weight;"
     print "    wRUsDonated=parseInt(wRUsDonated,10);"

#-----------------------------------------------------------------------------#
#  Figure out Average Time of Death results
#-----------------------------------------------------------------------------#

     print "    if ( !CarLost ) sTimeDied=\"00:00:00\";"
     print "    else {"
     print "      var wTimeDied=TimeDied/CarLost;"
     print "      var wTimeDiedH=wTimeDied/60;"
     print "      wTimeDiedH=parseInt(wTimeDiedH,10);"
     print "      var sTimeDiedH=wTimeDiedH.toString();"
     print "      if ( wTimeDiedH < 10 ) sTimeDiedH=\"0\"+sTimeDiedH;"
     print "      var wTimeDiedM=(wTimeDied-(wTimeDiedH*60));"
     print "      wTimeDiedM=parseInt(wTimeDiedM,10);"
     print "      var sTimeDiedM=wTimeDiedM.toString();"
     print "      if ( wTimeDiedM < 10 ) sTimeDiedM=\"0\"+sTimeDiedM;"
     print "      var wTimeDiedS=(wTimeDied-(wTimeDiedH*60)-wTimeDiedM)*60;"
     print "      wTimeDiedS=parseInt(wTimeDiedS,10);"
     print "      var sTimeDiedS=wTimeDiedS.toString();"
     print "      if ( wTimeDiedS < 10 ) sTimeDiedS=\"0\"+sTimeDiedS;"
     print "      sTimeDied=sTimeDiedH+\":\"+sTimeDiedM+\":\"+sTimeDiedS;"
     print "    }"
     print "//alert(\"TimeDied=\"+wTimeDied+\" sTimeDiedH=\"+sTimeDiedH+\" sTimeDiedM=\"+sTimeDiedM+\" sTimeDiedS=\"+sTimeDiedS);"

     print "    var wGameMins=GameMins/weight;"
     print "    wGameMins=parseInt(wGameMins,10);"
     print "    var wDiplomacyScore=DiplomacyScore/weight;"
     print "    wDiplomacyScore=parseInt(wDiplomacyScore,10);"
     print " "
     print "    document.main.RUsReceived.value=wRUsReceived;"
     print "    document.main.RUsDonated.value=wRUsDonated;"
     print "    document.main.TimeDied.value=sTimeDied;"
     print "    document.main.GameMins.value=wGameMins;"
     print "    document.main.DiplomacyScore.value=wDiplomacyScore;"
     print " "

#-----------------------------------------------------------------------------#
#  Figure out Career total results
#-----------------------------------------------------------------------------#

     print "    if ( CarWins ) {"
     print "      if ( CarLost ) {"
     print "        CarRatio=CarWins/CarLost;"
     print "        var sCarRatio=CarRatio.toString();"
     print "        sCarRatio=sCarRatio.substr(0,4);"
     print "        var pctCarRatio=(CarWins*100)/(CarWins+CarLost);"
     print "        var wpctCarRatio=parseInt(pctCarRatio,10);"
     print "        sCarRatio+=\" : 1 (\"+wpctCarRatio+\"%)\";"
     print "      } else var sCarRatio=\"ALL (100%)\";"
     print "    } else var sCarRatio=\"NONE\";"
     print " "
     print "    if ( ShipsKilled ) {"
     print "      if ( ShipsLost ) {"
     print "        CarKill=ShipsKilled/ShipsLost;"
     print "        var sCarKill=CarKill.toString();"
     print "        sCarKill=sCarKill.substr(0,4);"
     print "        sCarKill+=\" : 1\";"
     print "      } else var sCarKill=\"ALL\";"
     print "    } else var sCarKill=\"NONE\";"
     print " "
     print "    var wCarScore=CarScore/weight;"
     print "    wCarScore=parseInt(wCarScore,10);"
     print " "
     print "    document.main.CarWins.value=CarWins+CarLost;"
     print "    document.main.CarLost.value=CarWins+\" / \"+CarLost;"
     print "    document.main.CarRatio.value=sCarRatio;"
     print "    document.main.CarKill.value=sCarKill;"
     print "    document.main.CarScore.value=wCarScore;"
     print " "
     print "}"
     print " "

#-----------------------------------------------------------------------------#
#  Function to update Summary Table based on one selected game detail line
#-----------------------------------------------------------------------------#

     print "function pickSelectFromArray(selectCtrl, itemArray) {"
     print "var i, j;"
     print " "
     print "  j = document.main.TEMPLAT.value;"
     print " "
     print "    document.main.ShipsBuilt.value=itemArray[j][6];"
     print "    document.main.ShipsLost.value=itemArray[j][7];"
     print "    document.main.ShipsKilled.value=itemArray[j][8];"
     print "    document.main.ShipsCaptured.value=itemArray[j][9];"
     print "    document.main.CombatScore.value=itemArray[j][10];"
     print " "
     print "    document.main.RUsHarvested.value=itemArray[j][11];"
     print "    document.main.RUsSpent.value=itemArray[j][12];"
     print "    document.main.Collectors.value=itemArray[j][13];"
     print "    document.main.Refineries.value=itemArray[j][14];"
     print "    document.main.ResourceScore.value=itemArray[j][15];"
     print " "
     print "    document.main.ProdVessels.value=itemArray[j][16];"
     print "    document.main.Subsystems.value=itemArray[j][17];"
     print "    document.main.PctResearch.value=itemArray[j][18];"
     print "    document.main.RUsResearch.value=itemArray[j][19];"
     print "    document.main.BuildScore.value=itemArray[j][20];"
     print " "
     print "    document.main.RUsReceived.value=itemArray[j][21];"
     print "    document.main.RUsDonated.value=itemArray[j][22];"
     print "    document.main.TimeDied.value=itemArray[j][23];"
     print "    document.main.GameMins.value=itemArray[j][24];"
     print "    document.main.DiplomacyScore.value=itemArray[j][25];"
     print " "
     print "    if ( itemArray[j][23] == \"--:--:--\" ) {"
     print "      document.main.CarWins.value=1;"
     print "      document.main.CarLost.value=0;"
     print "      document.main.CarRatio.value=1;"
     print "    } else {"
     print "      document.main.CarWins.value=0;"
     print "      document.main.CarLost.value=1;"
     print "      document.main.CarRatio.value=0;"
     print "    }"
     print "    if ( itemArray[j][8] ) {"
     print "      if ( itemArray[j][7] ) {"
     print "        var gameKill=itemArray[j][8]/itemArray[j][7];"
     print "        var gCarKill=gameKill.toString();"
     print "        gCarKill=gCarKill.substr(0,4);"
     print "        gCarKill+=\" : 1\";"
     print "      } else gCarKill=\"ALL\";"
     print "    } else gCarKill=\"NONE\";"
     print "    document.main.CarKill.value=gCarKill;"
     print "    var gameScore=itemArray[j][10]+itemArray[j][15]+itemArray[j][20]+itemArray[j][25];"
     print "    document.main.CarScore.value=gameScore;"
     print " "
     print "//alert(\"List value=\"+j);"
     print " "
     print "}"
     print " "

     print "function displayGraph(selectCtrl, itemArray) {"
     print "var i, j=0, output, eIdx, gIdx, sIdx;"
     print " "

     print "  output='<HTML><HEAD><TITLE>Game Graph</TITLE>\\n';";
     print "  output+='<script type=\\\"text/javascript\\\">\\n';";
     print "  output+='var CalcType=1;\\n';";
     print "  output+='var headArry=new Array(\\\"Map\\\",\\\"Time Stamp\\\",\\\"Reserved\\\",\\\"Player\\\",\\\"Race\\\",\\\"Pos\\\",\\\"Ships Built\\\",\\\"Ships Lost\\\",\\\"Ships Killed\\\",\\\"Ships Captured\\\",\\\"Combat Score\\\",\\\"RUs Harvested\\\",\\\"RUs Spent\\\",\\\"Collectors\\\",\\\"Refineries\\\",\\\"Resource Score\\\",\\\"Prod Vessels\\\",\\\"Subsystems\\\",\\\"Pct Research\\\",\\\"RUs Research\\\",\\\"Build Score\\\",\\\"RUs Received\\\",\\\"RUs Donated\\\",\\\"TimeDied\\\",\\\"Game Mins\\\",\\\"Diplomacy Score\\\");\\n';";
     print "  output+='var statArry=new Array(\\n';";

#-----------------------------------------------------------------------------#
#  Loop through all Stats Array lines and process if flagged to display
#-----------------------------------------------------------------------------#

     print "  for (i = 0; i < ArryCNT ; i++) {"
     print "    if ( lineArry[i] == 1 ) {"
     print "      output+='new Array(\\\"'+statArry[i][0]+'\\\",\\\"'+statArry[i][1]+'\\\",\\\"'+statArry[i][2]+'\\\",\\\"'+statArry[i][3]+'\\\",\\\"'+statArry[i][4]+'\\\",\\\"'+statArry[i][5]+'\\\",'+statArry[i][6]+','+statArry[i][7]+','+statArry[i][8]+','+statArry[i][9]+','+statArry[i][10]+','+statArry[i][11]+','+statArry[i][12]+','+statArry[i][13]+','+statArry[i][14]+','+statArry[i][15]+','+statArry[i][16]+','+statArry[i][17]+','+statArry[i][18]+','+statArry[i][19]+','+statArry[i][20]+','+statArry[i][21]+','+statArry[i][22]+',\\\"'+statArry[i][23]+'\\\",'+statArry[i][24]+','+statArry[i][25]+'),\\n';";
     print "      j++"
     print "    }"
     print "  }"
     print "  output+='new Array(\\\" \\\",\\\" \\\")\\n';";
     print "  output+=');\\n';";
     print "  output+='var ArryCNT='+j+';\\n';";
     print "  output+='function normGroup(a,b) {\\n';";
     print "  output+='  if (a[0].toLowerCase()<b[0].toLowerCase()) return -1;\\n';";
     print "  output+='  if (a[0].toLowerCase()>b[0].toLowerCase()) return 1;\\n';";
     print "  output+='  return 0;\\n';";
     print "  output+='}\\n';";
     print "  output+='function revGroup(a,b) {\\n';";
     print "  output+='  if (a[0].toLowerCase()<b[0].toLowerCase()) return 1;\\n';";
     print "  output+='  if (a[0].toLowerCase()>b[0].toLowerCase()) return -1;\\n';";
     print "  output+='  return 0;\\n';";
     print "  output+='}\\n';";
     print "  output+='function normValue(a,b) {\\n';";
     print "  output+='  if (a[1]<b[1]) return -1;\\n';";
     print "  output+='  if (a[1]>b[1]) return 1;\\n';";
     print "  output+='  return 0;\\n';";
     print "  output+='}\\n';";
     print "  output+='function revValue(a,b) {\\n';";
     print "  output+='  if (a[1]<b[1]) return 1;\\n';";
     print "  output+='  if (a[1]>b[1]) return -1;\\n';";
     print "  output+='  return 0;\\n';";
     print "  output+='}\\n';";
     print "  output+='function changeCalc(newCalc) {\\n';";
     print "  output+='  CalcType = newCalc;\\n';";
     print "  output+='  changeSrc();\\n';";
     print "  output+='}\\n';";
     print "  output+='function changeSrc() {\\n';";
     print "  output+='  var barWidth, i, maxVal=0, oCount=0, oIdx=0, output, sGraphIt;\\n';";
     print "  output+='  var graphIt = document.main.graphIt.value;\\n';";
     print "  output+='  switch(graphIt) {\\n';";
     print "  output+='    case \\\"games\\\" :\\n';";
     print "  output+='      sGraphIt=\\\"Games\\\";\\n';";
     print "  output+='      document.main.CalcType.selectedIndex=0;\\n';";
     print "  output+='      break;\\n';";
     print "  output+='    case \\\"wins\\\" :\\n';";
     print "  output+='      sGraphIt=\\\"Wins\\\";\\n';";
     print "  output+='      document.main.CalcType.selectedIndex=0;\\n';";
     print "  output+='      break;\\n';";
     print "  output+='    case \\\"loses\\\" :\\n';";
     print "  output+='      sGraphIt=\\\"Losses\\\";\\n';";
     print "  output+='      document.main.CalcType.selectedIndex=0;\\n';";
     print "  output+='      break;\\n';";
     print "  output+='    case \\\"winratio\\\" :\\n';";
     print "  output+='      sGraphIt=\\\"Win Ratio\\\";\\n';";
     print "  output+='      document.main.CalcType.selectedIndex=1;\\n';";
     print "  output+='      break;\\n';";
     print "  output+='    case \\\"killratio\\\" :\\n';";
     print "  output+='      sGraphIt=\\\"Ships Killed Ratio\\\";\\n';";
     print "  output+='      document.main.CalcType.selectedIndex=1;\\n';";
     print "  output+='      break;\\n';";
     print "  output+='    case \\\"overall\\\" :\\n';";
     print "  output+='      sGraphIt=\\\"Overall Score\\\";\\n';";
     print "  output+='      break;\\n';";
     print "  output+='    default :\\n';";
     print "  output+='      sGraphIt=headArry[graphIt];\\n';";
     print "  output+='  }\\n';";
     print "  output+='  var groupBy = document.main.groupBy.value;\\n';";
     print "  output+='  var orderBy = document.main.orderBy.value;\\n';";
     print "  output+='  CalcType = eval(document.main.CalcType.value);\\n';";
     print "  output+='  var gArray = new Array(ArryCNT+1);\\n';";
     print "  output+='  for ( i=0 ; i<ArryCNT ; i++ ) {\\n';";
     print "  output+='    switch(graphIt) {\\n';";
     print "  output+='      case \\\"games\\\" :\\n';";
     print "  output+='        gArray[i]=new Array(statArry[i][groupBy],1,0);\\n';";
     print "  output+='        break;\\n';";
     print "  output+='      case \\\"wins\\\" :\\n';";
     print "  output+='        if ( statArry[i][23] == \\\"--:--:--\\\" ) gArray[i]=new Array(statArry[i][groupBy],1,0);\\n';";
     print "  output+='        else gArray[i]=new Array(statArry[i][groupBy],0,0);\\n';";
     print "  output+='        break;\\n';";
     print "  output+='      case \\\"loses\\\" :\\n';";
     print "  output+='        if ( statArry[i][23] != \\\"--:--:--\\\" ) gArray[i]=new Array(statArry[i][groupBy],1,0);\\n';";
     print "  output+='        else gArray[i]=new Array(statArry[i][groupBy],0,0);\\n';";
     print "  output+='        break;\\n';";
     print "  output+='      case \\\"winratio\\\" :\\n';";
     print "  output+='        if ( statArry[i][23] == \\\"--:--:--\\\" ) gArray[i]=new Array(statArry[i][groupBy],100,0);\\n';";
     print "  output+='        else gArray[i]=new Array(statArry[i][groupBy],0,0);\\n';";
     print "  output+='        break;\\n';";
     print "  output+='      case \\\"killratio\\\" :\\n';";
     print "  output+='        gArray[i]=new Array(statArry[i][groupBy],statArry[i][8],statArry[i][7]);\\n';";
     print "  output+='        break;\\n';";
     print "  output+='      case \\\"overall\\\" :\\n';";
     print "  output+='        gArray[i]=new Array(statArry[i][groupBy],statArry[i][10]+statArry[i][15]+statArry[i][20]+statArry[i][25],0);\\n';";
     print "  output+='        break;\\n';";
     print "  output+='      default :\\n';";
     print "  output+='        gArray[i]=new Array(statArry[i][groupBy],statArry[i][graphIt],0);\\n';";
     print "  output+='    }\\n';";
     print "  output+='  }\\n';";
     print "  output+='  if ( groupBy == 1 ) gArray.sort(revGroup);\\n';";
     print "  output+='                 else gArray.sort(normGroup);\\n';";
     print "  output+='  var oArray = new Array(ArryCNT+1);\\n';";
     print "  output+='  for ( i=0 ; i<ArryCNT ; i++ ) {\\n';";
     print "  output+='    if ( i == 0 ) {\\n';";
     print "  output+='      oArray[oIdx]=new Array(gArray[i][0],gArray[i][1],gArray[i][2]);\\n';";
     print "  output+='      oCount++;\\n';";
     print "  output+='    } else {\\n';";
     print "  output+='      if ( oArray[oIdx][0] != gArray[i][0] ) {\\n';";
     print "  output+='        if ( !CalcType ) {\\n';";
     print "  output+='          if ( graphIt == \\\"killratio\\\" ) {\\n';";
     print "  output+='            if ( oArray[oIdx][2] ) {\\n';";
     print "  output+='              oArray[oIdx][1]=(oArray[oIdx][1]/oArray[oIdx][2])*100;\\n';";
     print "  output+='              oArray[oIdx][1]=parseInt(oArray[oIdx][1],10);\\n';";
     print "  output+='            } else {\\n';";
     print "  output+='              oArray[oIdx][1]=\\\"ALL\\\";\\n';";
     print "  output+='            }\\n';";
     print "  output+='          } else {\\n';";
     print "  output+='            oArray[oIdx][1]=oArray[oIdx][1]/oCount;\\n';";
     print "  output+='            oArray[oIdx][1]=parseInt(oArray[oIdx][1],10);\\n';";
     print "  output+='          }\\n';";
     print "  output+='          oCount=0;\\n';";
     print "  output+='        }\\n';";
     print "  output+='        if ( oArray[oIdx][1] > maxVal ) maxVal=oArray[oIdx][1];\\n';";
     print "  output+='        oIdx++;\\n';";
     print "  output+='        oArray[oIdx]=new Array(gArray[i][0],gArray[i][1],gArray[i][2]);\\n';";
     print "  output+='        oCount++;\\n';";
     print "  output+='      } else {\\n';";
     print "  output+='        oArray[oIdx][1]+=gArray[i][1];\\n';";
     print "  output+='        oArray[oIdx][2]+=gArray[i][2];\\n';";
     print "  output+='        oCount++;\\n';";
     print "  output+='      }\\n';";
     print "  output+='    }\\n';";
     print "  output+='  }\\n';";
     print "  output+='  if ( !CalcType ) {\\n';";
     print "  output+='    if ( graphIt == \\\"killratio\\\" ) {\\n';";
     print "  output+='      if ( oArray[oIdx][2] ) {\\n';";
     print "  output+='        oArray[oIdx][1]=(oArray[oIdx][1]/oArray[oIdx][2])*100;\\n';";
     print "  output+='        oArray[oIdx][1]=parseInt(oArray[oIdx][1],10);\\n';";
     print "  output+='      } else {\\n';";
     print "  output+='        oArray[oIdx][1]=\\\"ALL\\\";\\n';";
     print "  output+='      }\\n';";
     print "  output+='    } else {\\n';";
     print "  output+='      oArray[oIdx][1]=oArray[oIdx][1]/oCount;\\n';";
     print "  output+='      oArray[oIdx][1]=parseInt(oArray[oIdx][1],10);\\n';";
     print "  output+='    }\\n';";
     print "  output+='  }\\n';";
     print "  output+='  if ( oArray[oIdx][1] > maxVal ) maxVal=oArray[oIdx][1];\\n';";
     print "  output+='  if ( orderBy == 1 ) oArray.sort(revValue);\\n';";
     print "  output+='  if ( orderBy == 2 ) oArray.sort(normValue);\\n';";
     print "  output+='  output=\\'<HTML><HEAD></HEAD>\\\\n\\';\\n';";
     print "  output+='  output+=\\'<BODY bgColor=black text=white>\\\\n\\';\\n';";
     print "  output+='  output+=\\'<table>\\\\n\\';\\n';";
     print "  output+='  for ( i=0 ; i<=oIdx ; i++ ) {\\n';";
     print "  output+='    if ( oArray[i][1] != \\\"ALL\\\" ) {\\n';";
     print "  output+='      barWidth=(oArray[i][1]/maxVal)*350;\\n';";
     print "  output+='      barWidth=parseInt(barWidth,10);\\n';";
     print "  output+='    } else {\\n';";
     print "  output+='      barWidth=350;\\n';";
     print "  output+='    }\\n';";
     print "  output+='    if ( graphIt == \\\"killratio\\\" ) {\\n';";
     print "  output+='      if ( oArray[i][1] != \\\"ALL\\\" ) {\\n';";
     print "  output+='        if ( oArray[i][1] != 0 ) {\\n';";
     print "  output+='          oArray[i][1]/=100;\\n';";
     print "  output+='          oArray[i][1]=oArray[i][1].toString();\\n';";
     print "  output+='          oArray[i][1]=oArray[i][1].substr(0,4);\\n';";
     print "  output+='          oArray[i][1]+=\\\" : 1\\\";\\n';";
     print "  output+='        } else oArray[i][1]=\\\"NONE\\\";\\n';";
     print "  output+='      }\\n';";
     print "  output+='    }\\n';";
     print "  output+='    output+=\\'<tr><td>\\'+oArray[i][0]+\\'</td>\\';\\n';";
     print "  output+='    output+=\\'<td valign=bottom>\\'\\n';";
     print "  output+='    if ( !barWidth ) output+=\\'|\\'\\n';";
     print "  output+='    else output+=\\'|<img src=graph_bar_gray.gif height=14 width=\\'+barWidth+\\'>\\'\\n';";
     print "  output+='    output+=\\' (\\'+oArray[i][1]+\\')</td></tr>\\\\n\\';\\n';";
     print "  output+='  }\\n';";
     print "  output+='  output+=\\'</table>\\\\n\\';\\n';";
     print "  output+='  output+=\\'</BODY></HTML>\\\\n\\';\\n';";
     print "  output+='  var wHandle = window.frames[\\\"myIframe\\\"].window;\\n';";
     print "  output+='  wHandle.document.open();\\n';";
     print "  output+='  wHandle.document.write(output);\\n';";
     print "  output+='  wHandle.document.close();\\n';";
     print "  output+='  if ( CalcType ) document.title=\\'Total \\'+sGraphIt+\\' by \\'+headArry[groupBy]+\\' Graph\\';\\n';";
     print "  output+='  else document.title=\\'Average \\'+sGraphIt+\\' by \\'+headArry[groupBy]+\\' Graph\\';\\n';";
     print "  output+='}\\n';";
     print "  output+='</script>\\n';";
     print "  output+='</head>\\n';";
     print "  output+='<body bgcolor=black text=cyan>\\n';";
     print "  output+='<form name=\\\"main\\\">\\n';";
     print "  output+='Graph: <select name=\\\"CalcType\\\" size=1 onChange=\\'changeSrc()\\'>\\n';";
     print "  output+='<option value=1 selected>Total</option>\\n';";
     print "  output+='<option value=0>Average</option>\\n';";
     print "  output+='</select>\\n';";
     print "  output+='<select name=\\\"graphIt\\\" size=1 onChange=\\'changeSrc()\\'>\\n';";
     print "  output+='<option value=\\\"games\\\" selected>Games</option>\\n';";
     print "  output+='<option value=\\\"wins\\\">Wins</option>\\n';";
     print "  output+='<option value=\\\"loses\\\">Losses</option>\\n';";
     print "  output+='<option value=\\\"winratio\\\">Win Ratio</option>\\n';";
     print "  output+='<option value=\\\"killratio\\\">Kill Ratio</option>\\n';";
     print "  output+='<option value=\\\"overall\\\">Overall Score</option>\\n';";
     print "  output+='<option value=6>Ships Built</option>\\n';";
     print "  output+='<option value=7>Ships Lost</option>\\n';";
     print "  output+='<option value=8>Ships Killed</option>\\n';";
     print "  output+='<option value=9>Ships Captured</option>\\n';";
     print "  output+='<option value=10>Combat Score</option>\\n';";
     print "  output+='<option value=11>RUs Harvested</option>\\n';";
     print "  output+='<option value=12>RUs Spent</option>\\n';";
     print "  output+='<option value=13>Collectors</option>\\n';";
     print "  output+='<option value=14>Refineries</option>\\n';";
     print "  output+='<option value=15>Resource Score</option>\\n';";
     print "  output+='<option value=16>Prod Vessels</option>\\n';";
     print "  output+='<option value=17>Subsystems</option>\\n';";
     print "  output+='<option value=18>Pct Research</option>\\n';";
     print "  output+='<option value=19>RUs Research</option>\\n';";
     print "  output+='<option value=20>Build Score</option>\\n';";
     print "  output+='<option value=21>RUs Received</option>\\n';";
     print "  output+='<option value=22>RUs Donated</option>\\n';";
     print "  output+='<option value=23>Time Died</option>\\n';";
     print "  output+='<option value=24>Game Mins</option>\\n';";
     print "  output+='<option value=25>Diplomacy Score</option>\\n';";
     print "  output+='</select>\\n';";
     print "  output+='- Group by:<select name=\\\"groupBy\\\" size=1 onChange=\\'changeSrc()\\'>\\n';";
     print "  output+='<option value=0 selected>Map</option>\\n';";
     print "  output+='<option value=1>Timestamp</option>\\n';";
     print "  output+='<option value=3>Player</option>\\n';";
     print "  output+='<option value=4>Race</option>\\n';";
     print "  output+='</select>\\n';";
     print "  output+='- Sort by:<select name=\\\"orderBy\\\" size=1 onChange=\\'changeSrc()\\'>\\n';";
     print "  output+='<option value=0 selected>Group</option>\\n';";
     print "  output+='<option value=1>High to Low</option>\\n';";
     print "  output+='<option value=2>Low to High</option>\\n';";
     print "  output+='</select>\\n';";
     print "  output+='<hr>\\n';";
     print "  output+='<iframe id=\\\"myIframe\\\" marginwidth=\\\"0\\\" marginheight=\\\"0\\\" frameborder=\\\"0\\\" height=\\\"90%\\\" width=\\\"100%\\\"></iframe>\\n';";
     print "  output+='</form>\\n';";
     print "  output+='<script type=\\\"text/javascript\\\">\\n';";
     print "  output+='changeSrc();\\n';";
     print "  output+='</script>\\n';";
     print "  output+='</body>\\n';";
     print "  output+='</html>\\n';";
     print " "

     print "  wHandle = window.open('', 'graph', 'toolbar=no,status=no,scrollbars=yes,resizable=yes,width=730,height=500');"
     print "  wHandle.document.write(output);"
     print " "
     print "}"
     print " "

     print "function displayPopUp(selectCtrl, itemArray) {"
     print "var i, j, output, eIdx, gIdx, sIdx;"
     print " "
     print "  gIdx = document.main.TEMPLAT.value;"
     print "  sIdx = parseInt(gIdx,10)-1;"
     print "  eIdx = parseInt(gIdx,10)+1;"
     print " "
     print "  output='<HTML><HEAD><TITLE>Game Details</TITLE></HEAD>\\n';";
     print "  output+='<BODY bgColor=black text=white>\\n';";
     print "  output+='<center><b>'+itemArray[gIdx][0]+' - '+itemArray[gIdx][1]+'</b></center>\\n';";
     print " "
     print "//alert(\"List value=\"+gIdx+\" start=\"+sIdx+\" end=\"+eIdx);"
     print "  while ( sIdx >= 0 && itemArray[gIdx][1] == itemArray[sIdx][1] && itemArray[gIdx][2] == itemArray[sIdx][2] ) sIdx--;"
     print "  sIdx++;"
     print "  while ( sIdx <= ArryCNT && itemArray[gIdx][1] == itemArray[eIdx][1] && itemArray[gIdx][2] == itemArray[eIdx][2] ) eIdx++;"
     print "  eIdx--;"
     print "//alert(\"List value=\"+gIdx+\" start=\"+sIdx+\" end=\"+eIdx);"
     print " "
     print "  for ( j=sIdx ; j<=eIdx ; j++ ) {"
     print " "
     print "    if ( itemArray[j][8] ) {"
     print "      if ( itemArray[j][7] ) {"
     print "        var gameKill=itemArray[j][8]/itemArray[j][7];"
     print "        var gCarKill=gameKill.toString();"
     print "        gCarKill=gCarKill.substr(0,4);"
     print "        gCarKill+=\" : 1\";"
     print "      }   else gCarKill=\"ALL\";"
     print "    } else gCarKill=\"NONE\";"
     print "    var gameScore=itemArray[j][10]+itemArray[j][15]+itemArray[j][20]+itemArray[j][25];"
     print " "
     print "    output+='<br><table border=1 cellpadding=2>\\n';";
     print "    output+='<tr>\\n';";
     print "    output+='<td rowspan=10 valign=center>&nbsp;'+itemArray[j][5]+'&nbsp; </td>\\n';";
     print "    output+='<td rowspan=2 valign=bottom>Career</td>\\n';";
     print "    output+='<td colspan=2><font size=1 color=cyan>Player Name</font></td>\\n';";
     print "    output+='<td><font size=1 color=cyan>Race</font></td>\\n';";
     print "    output+='<td><font size=1 color=cyan>Ship Kill Ratio</font></td>\\n';";
     print "    output+='<td><font size=1 color=cyan>Overall Score</font></td>\\n';";
     print "    output+='</tr>\\n';";
     print "    output+='<tr>\\n';";
     print "    output+='<td colspan=2>'+itemArray[j][3]+'</td>\\n';";
     print "    output+='<td>'+itemArray[j][4]+'</td>\\n';";
     print "    output+='<td>'+gCarKill+'</td>\\n';";
     print "    output+='<td>'+gameScore+'</td>\\n';";
     print "    output+='</tr>\\n';";
     print " "
     print "    output+='<tr>\\n';";
     print "    output+='<td rowspan=2 valign=bottom>Combat</td>\\n';";
     print "    output+='<td><font size=1 color=cyan>Ships Built</font></td>\\n';";
     print "    output+='<td><font size=1 color=cyan>Ships Lost</font></td>\\n';";
     print "    output+='<td><font size=1 color=cyan>Ships Killed</font></td>\\n';";
     print "    output+='<td><font size=1 color=cyan>Ships Captured</font></td>\\n';";
     print "    output+='<td><font size=1 color=cyan>Combat Score</font></td>\\n';";
     print "    output+='</tr>\\n';";
     print "    output+='<tr>\\n';";
     print "    output+='<td>'+itemArray[j][6]+'</td>\\n';";
     print "    output+='<td>'+itemArray[j][7]+'</td>\\n';";
     print "    output+='<td>'+itemArray[j][8]+'</td>\\n';";
     print "    output+='<td>'+itemArray[j][9]+'</td>\\n';";
     print "    output+='<td>'+itemArray[j][10]+'</td>\\n';";
     print "    output+='</tr>\\n';";
     print " "
     print "    output+='<tr>\\n';";
     print "    output+='<td rowspan=2 valign=bottom>Mining</td>\\n';";
     print "    output+='<td><font size=1 color=cyan>RUs Harvested</font></td>\\n';";
     print "    output+='<td><font size=1 color=cyan>RUs Spent</font></td>\\n';";
     print "    output+='<td><font size=1 color=cyan>Collectors</font></td>\\n';";
     print "    output+='<td><font size=1 color=cyan>Refineries</font></td>\\n';";
     print "    output+='<td><font size=1 color=cyan>Resource Score</font></td>\\n';";
     print "    output+='</tr>\\n';";
     print "    output+='<tr>\\n';";
     print "    output+='<td>'+itemArray[j][11]+'</td>\\n';";
     print "    output+='<td>'+itemArray[j][12]+'</td>\\n';";
     print "    output+='<td>'+itemArray[j][13]+'</td>\\n';";
     print "    output+='<td>'+itemArray[j][14]+'</td>\\n';";
     print "    output+='<td>'+itemArray[j][15]+'</td>\\n';";
     print "    output+='</tr>\\n';";
     print " "
     print "    output+='<tr>\\n';";
     print "    output+='<td rowspan=2 valign=bottom>Building</td>\\n';";
     print "    output+='<td><font size=1 color=cyan>Prod Ships</font></td>\\n';";
     print "    output+='<td><font size=1 color=cyan>Subsystems</font></td>\\n';";
     print "    output+='<td><font size=1 color=cyan>Research</font></td>\\n';";
     print "    output+='<td><font size=1 color=cyan>Research RUs</font></td>\\n';";
     print "    output+='<td><font size=1 color=cyan>Build Score</font></td>\\n';";
     print "    output+='</tr>\\n';";
     print "    output+='<tr>\\n';";
     print "    output+='<td>'+itemArray[j][16]+'</td>\\n';";
     print "    output+='<td>'+itemArray[j][17]+'</td>\\n';";
     print "    output+='<td>'+itemArray[j][18]+'%</td>\\n';";
     print "    output+='<td>'+itemArray[j][19]+'</td>\\n';";
     print "    output+='<td>'+itemArray[j][20]+'</td>\\n';";
     print "    output+='</tr>\\n';";
     print " "
     print "    output+='<tr>\\n';";
     print "    output+='<td rowspan=2 valign=bottom>Diplomacy</td>\\n';";
     print "    output+='<td><font size=1 color=cyan>RUs Received</font></td>\\n';";
     print "    output+='<td><font size=1 color=cyan>RUs Donated</font></td>\\n';";
     print "    output+='<td><font size=1 color=cyan>Time of Death</font></td>\\n';";
     print "    output+='<td><font size=1 color=cyan>Game Minutes</font></td>\\n';";
     print "    output+='<td><font size=1 color=cyan>Diplomacy Score</font></td>\\n';";
     print "    output+='</tr>\\n';";
     print "    output+='<tr>\\n';";
     print "    output+='<td>'+itemArray[j][21]+'</td>\\n';";
     print "    output+='<td>'+itemArray[j][22]+'</td>\\n';";
     print "    output+='<td>'+itemArray[j][23]+'</td>\\n';";
     print "    output+='<td>'+itemArray[j][24]+'</td>\\n';";
     print "    output+='<td>'+itemArray[j][25]+'</td>\\n';";
     print "    output+='</tr>\\n';";
     print "    output+='</table>\\n';";

     print "  }"

     print "  output+='</BODY></HTML>\\n';";
     print " "
     print "  wHandle = window.open('', 'details', 'toolbar=no,status=no,scrollbars=yes,resizable=yes,width=550,height=400');"
     print "  wHandle.document.write(output);"
     print " "
     print "}"

     print " "
     print "//  End -->"
     print "</script>"
     print " "

#-----------------------------------------------------------------------------#
#  End of JavaScript code, build HTML form body
#-----------------------------------------------------------------------------#

     print "  </HEAD>"
     print "  <BODY bgcolor=#000000 text=#0FFFFF link=#FFFFFF alink=#F0F000 vlink=#FFFFFF>"
     print " "
     print "  <form name=\"main\" method=\"get\" action=\"msd.html\">"
     print " "

#-----------------------------------------------------------------------------#
#  Add Map selection Pull-Down
#-----------------------------------------------------------------------------#

     print "<font color=white>Filters</font> - "

     print "Map:<input type=\"checkbox\" name=\"MapFilter\" value=\"1\" "
     print "       onClick='fillLineArray(this.form.TEMPLAT, statArry, 0);'><select name=\"COL0\" size=1  "
     print "       onChange='document.main.MapFilter.checked=1;fillLineArray(this.form.TEMPLAT, statArry, 0);'>"
     for ( idx in cntMap ) mapArry[mapCnt++]=idx
     rc=asort(mapArry)
     maxLen=0
     for ( idx=1 ; idx<mapCnt ; idx++ ) {
       if( length(mapArry[idx]) > maxLen ) maxLen = length(mapArry[idx])
       printf("<option value=\"%s\">%s (%d)</option>\n",mapArry[idx],mapArry[idx],cntMap[mapArry[idx]])
     }
     print "</select></nobr><input type=hidden name=\"COLSZ0\" value="maxLen+3">"
     print " "
     print "<input type=hidden name=\"COLSZ1\" value=19>"
     print " "

#-----------------------------------------------------------------------------#
#  Add Player selection Pull-Down
#-----------------------------------------------------------------------------#

     print "Player:<input type=\"checkbox\" name=\"PlayerFilter\" value=\"1\" checked"
     print "        onClick='fillLineArray(this.form.TEMPLAT, statArry, 3);'><select name=\"COL3\" size=1  "
     print "        onChange='document.main.PlayerFilter.checked=1;fillLineArray(this.form.TEMPLAT, statArry, 3);'>"
     for ( idx in cntName ) plyArry[plyCnt++]=sprintf("%s %s",tolower(idx),idx)
     rc=asort(plyArry)
     maxLen=0
     for ( idx=1 ; idx<plyCnt ; idx++ ) {
       plyName=substr(plyArry[idx],index(plyArry[idx]," ")+1)
       if( length(plyName) > maxLen ) maxLen = length(plyName)
       if( cntName[plyName] != maxGames ) {
         printf("<option value=\"%s\">%s (%d)</option>\n",plyName,plyName,cntName[plyName])
       } else {
         printf("<option value=\"%s\" selected>%s (%d)</option>\n",plyName,plyName,cntName[plyName])
       }
     }
     print "</select></nobr><input type=hidden name=\"COLSZ3\" value="maxLen+3">"
     print " "
     print "<input type=hidden name=\"COLSZ2\" value=8>"
     print " "

#-----------------------------------------------------------------------------#
#  Add Race selection Pull-Down
#-----------------------------------------------------------------------------#

     print "Race:<input type=\"checkbox\" name=\"RaceFilter\" value=\"1\" "
     print "      onClick='fillLineArray(this.form.TEMPLAT, statArry, 4);'><select name=\"COL4\" size=1  "
     print "      onChange='document.main.RaceFilter.checked=1;fillLineArray(this.form.TEMPLAT, statArry, 4);'>"
     for ( idx in cntRace ) racArry[racCnt++]=idx
     rc=asort(racArry)
     maxLen=0
     for ( idx=1 ; idx<racCnt ; idx++ ) {
       if( length(racArry[idx]) > maxLen ) maxLen = length(racArry[idx])
       printf("<option value=\"%s\">%s (%d)</option>\n",racArry[idx],racArry[idx],cntRace[racArry[idx]])
     }
     print "</select></nobr><input type=hidden name=\"COLSZ4\" value="maxLen+3">"
     print " "
     print "<input type=hidden name=\"COLSZ5\" value=4>"
     print " "
     print "<input type=hidden name=\"COLSZ23\" value=8>"
     print " "
     print "  <hr>"
     print " "

#-----------------------------------------------------------------------------#
#  Display Game Summary Table
#-----------------------------------------------------------------------------#

     print "<table>"
     print "<tr>"
     print "<td rowspan=10> &nbsp; &nbsp; &nbsp; </td>"
     print "<td rowspan=2 valign=bottom>Career</td>"
     print "<td><font size=1>Total Games</font></td>"
     print "<td><font size=1>Wins / Losses</font></td>"
     print "<td><font size=1>Win Ratio</font></td>"
     print "<td><font size=1>Ship Kill Ratio</font></td>"
     print "<td><font size=1>Overall Score</font></td>"
     print "<td rowspan=2 valign=center>"
     print "<input type=\"button\" name=\"graphBut\" value=\" Bar Charts \" onClick=\"displayGraph();\">"
     print "</td>"
     print "</tr>"
     print "<tr>"
     print "<td><input type=text name=CarWins size=11></td>"
     print "<td><input type=text name=CarLost size=11></td>"
     print "<td><input type=text name=CarRatio size=11></td>"
     print "<td><input type=text name=CarKill size=11></td>"
     print "<td><input type=text name=CarScore size=12></td>"
     print "</tr>"

#-----------------------------------------------------------------------------#
#  Display Combat Line
#-----------------------------------------------------------------------------#

     print "<tr>"
     print "<td rowspan=2 valign=bottom>Combat</td>"
     print "<td><font size=1>Ships Built</font></td>"
     print "<td><font size=1>Ships Lost</font></td>"
     print "<td><font size=1>Ships Killed</font></td>"
     print "<td><font size=1>Ships Captured</font></td>"
     print "<td><font size=1>Combat Score</font></td>"
     print "<td rowspan=2>"
     print "<input type=\"radio\" name=\"CalcType\" value=\"1\" checked"
     print "          onClick=\"fillTableStats(1);\">Totals<br>"
     print "<input type=\"radio\" name=\"CalcType\" value=\"0\""
     print "          onClick=\"fillTableStats(0);\">Average"
     print "</td>"
     print "</tr>"
     print "<tr>"
     print "<td><input type=text name=ShipsBuilt size=11></td>"
     print "<td><input type=text name=ShipsLost size=11></td>"
     print "<td><input type=text name=ShipsKilled size=11></td>"
     print "<td><input type=text name=ShipsCaptured size=11></td>"
     print "<td><input type=text name=CombatScore size=12></td>"
     print "</tr>"

#-----------------------------------------------------------------------------#
#  Display Mining Line
#-----------------------------------------------------------------------------#

     print "<tr>"
     print "<td rowspan=2 valign=bottom>Mining</td>"
     print "<td><font size=1>RUs Harvested</font></td>"
     print "<td><font size=1>RUs Spent</font></td>"
     print "<td><font size=1>Collectors</font></td>"
     print "<td><font size=1>Refineries</font></td>"
     print "<td><font size=1>Resource Score</font></td>"
     print "</tr>"
     print "<tr>"
     print "<td><input type=text name=RUsHarvested size=11></td>"
     print "<td><input type=text name=RUsSpent size=11></td>"
     print "<td><input type=text name=Collectors size=11></td>"
     print "<td><input type=text name=Refineries size=11></td>"
     print "<td><input type=text name=ResourceScore size=12></td>"
     print "</tr>"

#-----------------------------------------------------------------------------#
#  Display Building Line
#-----------------------------------------------------------------------------#

     print "<tr>"
     print "<td rowspan=2 valign=bottom>Building</td>"
     print "<td><font size=1>Prod Ships</font></td>"
     print "<td><font size=1>Subsystems</font></td>"
     print "<td><font size=1>Research</font></td>"
     print "<td><font size=1>Research RUs</font></td>"
     print "<td><font size=1>Build Score</font></td>"
     print "</tr>"
     print "<tr>"
     print "<td><input type=text name=ProdVessels size=11></td>"
     print "<td><input type=text name=Subsystems size=11></td>"
     print "<td><input type=text name=PctResearch size=7>%</td>"
     print "<td><input type=text name=RUsResearch size=11></td>"
     print "<td><input type=text name=BuildScore size=12></td>"
     print "</tr>"

#-----------------------------------------------------------------------------#
#  Display Diplomacy Line
#-----------------------------------------------------------------------------#

     print "<tr>"
     print "<td rowspan=2 valign=bottom>Diplomacy</td>"
     print "<td><font size=1>RUs Received</font></td>"
     print "<td><font size=1>RUs Donated</font></td>"
     print "<td><font size=1>Time of Death</font></td>"
     print "<td><font size=1>Game Minutes</font></td>"
     print "<td><font size=1>Diplomacy Score</font></td>"
     print "</tr>"
     print "<tr>"
     print "<td><input type=text name=RUsReceived size=11></td>"
     print "<td><input type=text name=RUsDonated size=11></td>"
     print "<td><input type=text name=TimeDied size=11></td>"
     print "<td><input type=text name=GameMins size=11></td>"
     print "<td><input type=text name=DiplomacyScore size=12></td>"
     print "</tr>"
     print "</table>"
     print " "
     print "  <hr>"
     print " "

#-----------------------------------------------------------------------------#
#  Display Game Detail Line Header
#-----------------------------------------------------------------------------#

     print "  <select name=HEADER size=1 style=\"font-family: Courier; font-size: 12\">"
     print "  <option>...please wait...</option>"
     print "  </select><br>"
     print " "

#-----------------------------------------------------------------------------#
#  Display Game Detail Line Display area
#-----------------------------------------------------------------------------#

     print "  <select name=TEMPLAT size=10 style=\"font-family: Courier; font-size: 12\" "
     print "          onChange=\"displayPopUp(this.form.TEMPLAT, statArry);\">"
     print "   <option>...analyzing information...</option>"
     print "  </select></font>"
     print " "
     print "  <hr>"
     print " "

#-----------------------------------------------------------------------------#
#  Display Status Line and Display area fill selection
#-----------------------------------------------------------------------------#

     print "  STATUS: <input name=SYSTATUS type=text size=34 value=\"LOADING FROM "aryCnt" LINE SOURCE\">"
     print "  - SHOW: <select name=RECLST size=1 "
     print "                  onChange=\"fillLineArray(this.form.TEMPLAT, statArry, 0);\">"
     print "<option value=100 selected>100</option>"
     print "<option value=500>500</option>"
     print "<option value=1000>1000</option>"
     print "<option value=2000>2000</option>"
     print "          </select> "
     print " - <input type=\"checkbox\" name=\"ShortGames\" value=\"1\" checked"
     print "          onClick='fillLineArray(this.form.TEMPLAT, statArry, 0);'>"
     print " Remove games under "ShortGame" mins"
     print "   <hr><br>"
     print " "
     print " </form>"
     print " "

#-----------------------------------------------------------------------------#
#  End of HTML form, fire off initial population of page
#-----------------------------------------------------------------------------#

     print "<SCRIPT LANGUAGE=\"JavaScript\">"
     print "<!-- Begin"
     print "statArry.sort(sortByTime);"
     print "fillLineArray(document.main.TEMPLAT, statArry, 0);"
     print "//  End -->"
     print "</script>"
     print " "

#-----------------------------------------------------------------------------#
#  End of HTML Page
#-----------------------------------------------------------------------------#

     print "</BODY></HTML>"
    }

#-----------------------------------------------------------------------------#
#  End of AWK program
#-----------------------------------------------------------------------------#
